@@ -10,13 +10,29 @@ from plans.models import Order
 def view_that_asks_for_money(request, order_id):
     order = get_object_or_404(Order, pk=order_id)
 
+    period = order.pricing.period
+    duration_unit = "D"
+
+    if period > 90:  # PayPal accepts max 90 days
+        duration_unit = "W"
+        period /= 7
+
+    # Dividing into months isn't very precise, so we don't do it
+    # if period > 52:  # PayPal accepts max 52 weeks
+    #     duration_unit = "M"
+    #     period = order.pricing.period / 30
+
+    if period > 24:  # PayPal accepts max 24 months
+        duration_unit = "Y"
+        period = order.pricing.period / 365
+
     # What you want the button to do.
     paypal_dict = {
         "cmd": "_xclick-subscriptions",
         "business": settings.PAYPAL_BUSSINESS_EMAIL,
         "a3": str(order.total()),                      # monthly price
-        "p3": order.pricing.period,                           # duration of each unit (depends on unit)
-        "t3": "D",                         # duration unit ("M for Month")
+        "p3": period,                           # duration of each unit (depends on unit)
+        "t3": duration_unit,                         # duration unit ("M for Month")
         "src": "1",                        # make payments recur
         "sra": "1",                        # reattempt payment on payment error
         "no_note": "1",                    # remove extra notes (optional)
